#
# spec file for package perl-MP3-Info
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MP3-Info
Name:           perl-MP3-Info
Version:        1.250.0
Release:        1699.4.pm.2
# 1.25 -> normalize -> 1.250.0
%define cpan_version 1.25
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Manipulate / fetch info from MP3 audio files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JM/JMERELO/%{cpan_name}-1.26.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.36
Provides:       perl(MP3::Info) = 1.260.0
%undefine       __perllib_provides
%{perl_requires}

%description
* $mp3 = MP3::Info->new(FILE)

OOP interface to the rest of the module. The same keys available via
get_mp3info and get_mp3tag are available via the returned object (using
upper case or lower case; but note that all-caps "VERSION" will return the
module version, not the MP3 version).

Passing a value to one of the methods will set the value for that tag in
the MP3 file, if applicable.

%prep
%autosetup  -n %{cpan_name}-1.26

%build
PERL_USE_UNSAFE_INC=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Mon Oct  9 2017 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-MP3-Info/Changes
* Tue Oct  3 2017 coolo@suse.com
- updated to 1.25
  see /usr/share/doc/packages/perl-MP3-Info/Changes
* Thu Apr 16 2015 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-MP3-Info/Changes
  * v1.24 Sat Nov  8 17:05:15 PST 2008
  * RT #13970: get_mp3info goes into infinite loop if no 0xFF byte in file
  * Fix VBR check for files that have Info header.
  * Add VBRI check from KDF.
  * Fix parsing of id3v2 APIC frame when it uses UTF8 encoding
  * Support new WAV id3v2 block type, ID32 - Andy Grundman
  * Handle ULT like USLT
* Thu Apr 16 2015 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-MP3-Info/Changes
  * v1.24 Sat Nov  8 17:05:15 PST 2008
  * RT #13970: get_mp3info goes into infinite loop if no 0xFF byte in file
  * Fix VBR check for files that have Info header.
  * Add VBRI check from KDF.
  * Fix parsing of id3v2 APIC frame when it uses UTF8 encoding
  * Support new WAV id3v2 block type, ID32 - Andy Grundman
  * Handle ULT like USLT
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sat Aug 11 2007 tsieden@suse.de
-  update to release 1.23
  * Handle all tags with NULL delimited lists - Patch from Justin Fletcher <gerph (at) gerph.org>
  * Fix MP3::Info for tag reading in AIF (and WAV, presumably) - kdf
  * Read RVA2 (signed short) in big-endian order - andyg
* Fri Mar 30 2007 tsieden@suse.de
-  update to release 1.22
  * Backwards compatibility for Apache::MP3 & others not expecting array refs.
  * Use Encode::Detect if available.
  * Parse Xing, Lame & Lyrics headers.
  * Big patch from Justin Fletcher for proper ID3v2.4 frame parsing.
  * Fix for ID3v2.2 frames in a v2.3 header - iTunes stupidity. - dsully
  * Allow multiple null separated "name" TCON values per the v2.4 spec.
  * New maintainer & Sponsor:
  * Read ReplayGain Information in:
  - RVA, RVAD and RVA2 tags.
  - COMM tags via J.River Media Center
  - PRIV tags via Windows Media Player
  * Unicode / Encode optimizations to only guess if the string isn't ascii.
  * Proper numeric genre decoding, now in tune with the ID3 spec.
  * Parse and return PIC & APIC data.
  * Handle multiple COMM and TCON tags.
  * Parse APE tags that are in the ID3v1 header space.
  * Parse USLT - Lyrics tags, used by iTunes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Apr 13 2005 tsieden@suse.de
- initial release 1.13
